'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

if (!global.Intl) {
  // No `Intl`, so use and load the polyfill.
  global.Intl = require('intl');
}

var React = require('react');
var ReactIntl = require('react-intl');
var IntlProvider = ReactIntl.IntlProvider;
var FormattedMessage = ReactIntl.FormattedMessage;
var TextBlockEditor = require('./TextBlockEditor');
var IndexBlockEditor = require('./IndexBlockEditor');
var PropTypes = require('prop-types');

/**
 * @class TextBlockComponent
 *
 * This class will recursively interpret a textblock, thus it might hold
 * some instances of itself.
 *
 * @member {String} prefix The prefix for all control names
 * @member {String} proto The proto in use (determines if we should do index or not)
 * @member {Object} block A Textblock.
 */

var TextBlockComponent = function (_React$Component) {
  _inherits(TextBlockComponent, _React$Component);

  function TextBlockComponent(props) {
    _classCallCheck(this, TextBlockComponent);

    var _this = _possibleConstructorReturn(this, (TextBlockComponent.__proto__ || Object.getPrototypeOf(TextBlockComponent)).call(this, props));

    if (_this.props.block) {
      _this.state = _this.props.block;
    } else {
      _this.state = {};
    }
    _this.addText = _this.addText.bind(_this);
    _this.addQuery = _this.addQuery.bind(_this);
    _this.deleteBlock = _this.deleteBlock.bind(_this);
    _this.handleUpdateBase = _this.handleUpdateBase.bind(_this);
    _this.handleUpdate = _this.handleUpdate.bind(_this);
    return _this;
  }

  _createClass(TextBlockComponent, [{
    key: 'addText',
    value: function addText(e) {
      e.preventDefault();
      var blocks;
      if (this.state.format === 'section') {
        blocks = this.state.blocks;
      } else {
        blocks = [this.state];
      }
      blocks.push({ format: 'html', source: '' });
      this.setState({ blocks: blocks,
        format: 'section' });
    }
  }, {
    key: 'addQuery',
    value: function addQuery(e) {
      e.preventDefault();
      var blocks;
      if (this.state.format === 'section') {
        blocks = this.state.blocks;
      } else {
        blocks = [this.state];
      }
      blocks.push({ query: "parents",
        format: "indexfeed" });
      this.setState({ blocks: blocks,
        format: 'section' });
    }
  }, {
    key: 'deleteBlock',
    value: function deleteBlock(i, e) {
      e.preventDefault();
      var blocks = this.state.blocks;
      blocks.splice(i, 1);
      this.setState({ blocks: blocks });
    }
  }, {
    key: 'handleUpdateBase',
    value: function handleUpdateBase(key, val) {
      var partialState = {};
      partialState[key] = value;
      this.setState(partialState);
    }
  }, {
    key: 'handleUpdate',
    value: function handleUpdate(block, key, val) {
      var blocks;
      if (this.state.format === 'section') {
        blocks = this.state.blocks;
      } else {
        blocks = [this.state];
      }
      blocks[block][key] = val;
      this.setState({ blocks: blocks });
    }
  }, {
    key: 'render',
    value: function render() {
      var buttons;
      if (this.props.proto === 'index') {
        buttons = React.createElement(
          'div',
          { className: 'pure-g-r' },
          React.createElement(
            'button',
            { onClick: this.addText, className: 'pure-button', id: 'addText' },
            'Add Text Section'
          ),
          React.createElement(
            'button',
            { onClick: this.addQuery, className: 'pure-button', id: 'addQuery' },
            'Add Query Section'
          )
        );
      } else {
        buttons = React.createElement(
          'div',
          { className: 'pure-g-r' },
          React.createElement(
            'button',
            { onClick: this.addText, className: 'pure-button', id: 'addText' },
            'Add Text Section'
          )
        );
      }

      if (this.state.format === 'section') {
        var self = this;
        var blocks = this.state.blocks.map(function (block, i) {
          var topButton, outBlock;
          if (i !== 0) {
            topButton = React.createElement(
              'div',
              { style: { 'font-size': '6pt', 'background': '#eee' } },
              React.createElement(
                'button',
                { key: 'x_' + i,
                  onClick: self.deleteBlock.bind(self, i), className: 'pure-button' },
                '\u2716'
              )
            );
          }
          if (block.format === 'indexfeed') {
            outBlock = React.createElement(IndexBlockEditor, { key: 'b_' + i,
              prefix: self.props.prefix + '[blocks][' + i + ']',
              block: block, handleUpdate: self.handleUpdate.bind(self, i) });
          } else {
            outBlock = React.createElement(TextBlockEditor, { key: 'b_' + i,
              prefix: self.props.prefix + '[blocks][' + i + ']',
              block: block, handleUpdate: self.handleUpdate.bind(self, i) });
          }
          return React.createElement(
            'div',
            { key: i, className: 'textblockbox' },
            topButton,
            outBlock
          );
        });
        return React.createElement(
          IntlProvider,
          { messages: this.props.messages, locale: 'en' },
          React.createElement(
            'fieldset',
            null,
            React.createElement('input', { type: 'hidden', value: 'section', name: this.props.prefix + '[format]',
              id: this.props.prefix + '[format]' }),
            blocks,
            buttons
          )
        );
      } else {
        var block;
        if (this.state.format === 'indexfeed') {
          block = React.createElement(IndexBlockEditor, {
            prefix: this.props.prefix,
            block: this.state, handleUpdate: this.handleUpdateBase, child: 'false' });
        } else {
          block = React.createElement(TextBlockEditor, {
            prefix: this.props.prefix,
            block: this.state, handleUpdate: this.handleUpdateBase, child: 'false' });
        }
        return React.createElement(
          IntlProvider,
          { messages: this.props.messages, locale: 'en' },
          React.createElement(
            'fieldset',
            null,
            block,
            buttons
          )
        );
      }
    }
  }]);

  return TextBlockComponent;
}(React.Component);

;

exports.TextBlockComponent = TextBlockComponent;